Trait google_appsactivity1::client::Part [−][src]
Identifies types which are only used as part of other types, which
usually are carrying the Resource trait.
Identifies types which are only used as part of other types, which
usually are carrying the Resource trait.
impl Part for Activity[src]impl Part for Event[src]impl Part for Move[src]impl Part for Parent[src]impl Part for Permission[src]impl Part for PermissionChange[src]impl Part for Photo[src]impl Part for Rename[src]impl Part for Target[src]impl Part for User[src]