Struct google_appsactivity1::ActivityMethods
source · pub struct ActivityMethods<'a, C, A>where
C: 'a,
A: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on activity resources.
It is not used directly, but through the Appsactivity hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_appsactivity1 as appsactivity1;
use std::default::Default;
use oauth2::{Authenticator, DefaultAuthenticatorDelegate, ApplicationSecret, MemoryStorage};
use appsactivity1::Appsactivity;
let secret: ApplicationSecret = Default::default();
let auth = Authenticator::new(&secret, DefaultAuthenticatorDelegate,
hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())),
<MemoryStorage as Default>::default(), None);
let mut hub = Appsactivity::new(hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `list(...)`
// to build up your call.
let rb = hub.activities();Implementations
sourceimpl<'a, C, A> ActivityMethods<'a, C, A>
impl<'a, C, A> ActivityMethods<'a, C, A>
sourcepub fn list(&self) -> ActivityListCall<'a, C, A>
pub fn list(&self) -> ActivityListCall<'a, C, A>
Create a builder to help you perform the following task:
Returns a list of activities visible to the current logged in user. Visible activities are determined by the visiblity settings of the object that was acted on, e.g. Drive files a user can see. An activity is a record of past events. Multiple events may be merged if they are similar. A request is scoped to activities from a given Google service using the source parameter.